@@ -29,7 +29,7 @@ use GRID::Machine::MakeAccessors; # Order is important. This must be the first!
 use GRID::Machine::Message;
 use GRID::Machine::Result;
 
-our $VERSION = "0.113";
+our $VERSION = "0.114";
 
 my %_taken_id;
 {
@@ -455,6 +455,14 @@ HELPMSG
               $r 
             },
          ],
+         [ 'async',   filter=>'result',
+            around => sub { 
+              my $self = shift; 
+              my $r = $self->call( 'async', @_ ); 
+              $r->{machine} = $self; 
+              $r 
+            },
+         ],
          [ 'waitpid', filter=>'result', ],
          [ 'waitall', filter=>'result', ],
          [ 'kill',    filter=>'result', ],
